# OPS03-BP02: Team members are empowered

## Description

Team được trao quyền để đưa ra quyết định.

## Implementation Guidance

- Decision-making authority delegated to teams
- Clear decision boundaries defined
- Teams can make changes without excessive approval
- Autonomy in technical decisions
- Trust-based management approach

## Risk Level

Medium - Disempowered teams are slow and demotivated.
